=== modified file 'NEWS'
--- NEWS	2008-07-02 01:40:02 +0000
+++ NEWS	2008-07-03 10:44:34 +0000
@@ -65,6 +65,9 @@
     * revision_history now tolerates mainline ghosts for Branch format 6.
       (Aaron Bentley, #235055)
 
+    * Set locale from environment for third party libs.
+      (Martin von Gagern, #128496)
+
   DOCUMENTATION:
 
     * Updated developer documentation.

=== modified file 'bzr'
--- bzr	2008-06-17 01:29:47 +0000
+++ bzr	2008-07-03 10:44:34 +0000
@@ -59,6 +59,35 @@
     profile_imports.install()
     profiling = True
 
+if sys.platform == 'darwin':
+    # jameinel says this hack is to force python to honor the LANG setting,
+    # even on Darwin.  Otherwise it is apparently hardcoded to Mac-Roman,
+    # which is incorrect for the normal Terminal.app which wants UTF-8.  
+    #
+    # "It might be that I should be setting the "system locale" somewhere else
+    # on the system, rather than setting LANG=en_US.UTF-8 in .bashrc.
+    # Switching to 'posix' and setting LANG worked for me." 
+    #
+    # So we can remove this if someone works out the right way to tell Mac
+    # Python which encoding to use.  -- mbp 20080703
+    sys.platform = 'posix'
+    try:
+        import locale
+    finally:
+        sys.platform = 'darwin'
+else:
+    import locale
+
+try:
+    locale.setlocale(locale.LC_ALL, '')
+except locale.Error, e:
+    sys.stderr.write('bzr: warning: %s\n'
+                     '  bzr could not set the application locale.\n'
+                     '  Although this should be no problem for bzr itself,\n'
+                     '  it might cause problems with some plugins.\n'
+                     '  To investigate the issue, look at the output\n'
+                     '  of the locale(1p) tool available on POSIX systems.\n'
+                     % e)
 
 try:
     import bzrlib

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2008-06-11 03:56:46 +0000
+++ bzrlib/osutils.py	2008-06-26 17:18:55 +0000
@@ -641,6 +641,7 @@
     offset = datetime.fromtimestamp(t) - datetime.utcfromtimestamp(t)
     return offset.days * 86400 + offset.seconds
 
+weekdays = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
     
 def format_date(t, offset=0, timezone='original', date_fmt=None,
                 show_offset=True):
@@ -672,6 +673,8 @@
         offset_str = ' %+03d%02d' % (offset / 3600, (offset / 60) % 60)
     else:
         offset_str = ''
+    # day of week depends on locale, so we do this ourself
+    date_fmt = date_fmt.replace('%a', weekdays[tt[6]])
     return (time.strftime(date_fmt, tt) +  offset_str)
 
 

=== modified file 'bzrlib/tests/blackbox/test_locale.py'
--- bzrlib/tests/blackbox/test_locale.py	2007-08-31 00:35:37 +0000
+++ bzrlib/tests/blackbox/test_locale.py	2008-06-26 17:18:55 +0000
@@ -65,6 +65,12 @@
         # as the first part of the string. It may be a little tempermental
         self.assertEqualDiff("""\
 bzr: warning: unsupported locale setting
+  bzr could not set the application locale.
+  Although this should be no problem for bzr itself,
+  it might cause problems with some plugins.
+  To investigate the issue, look at the output
+  of the locale(1p) tool available on POSIX systems.
+bzr: warning: unsupported locale setting
   Could not determine what text encoding to use.
   This error usually means your Python interpreter
   doesn't support the locale set by $LANG (BOGUS)

=== modified file 'bzrlib/timestamp.py'
--- bzrlib/timestamp.py	2008-04-24 07:22:53 +0000
+++ bzrlib/timestamp.py	2008-06-26 17:18:55 +0000
@@ -56,7 +56,8 @@
         offset = 0
     tt = time.gmtime(t + offset)
 
-    return (time.strftime("%a %Y-%m-%d %H:%M:%S", tt)
+    return (osutils.weekdays[tt[6]] +
+            time.strftime(" %Y-%m-%d %H:%M:%S", tt)
             # Get the high-res seconds, but ignore the 0
             + ('%.9f' % (t - int(t)))[1:]
             + ' %+03d%02d' % (offset / 3600, (offset / 60) % 60))
@@ -100,6 +101,11 @@
     ...      break
 
     """
+    # Weekday parsing is locale sensitive, so drop the weekday
+    space_loc = date.find(' ')
+    if space_loc == -1 or date[:space_loc] not in osutils.weekdays:
+        raise ValueError(
+            'Date string does not contain a day of week: %r' % date)
     # Up until the first period is a datestamp that is generated
     # as normal from time.strftime, so use time.strptime to
     # parse it
@@ -107,7 +113,7 @@
     if dot_loc == -1:
         raise ValueError(
             'Date string does not contain high-precision seconds: %r' % date)
-    base_time = time.strptime(date[:dot_loc], "%a %Y-%m-%d %H:%M:%S")
+    base_time = time.strptime(date[space_loc:dot_loc], " %Y-%m-%d %H:%M:%S")
     fract_seconds, offset = date[dot_loc:].split()
     fract_seconds = float(fract_seconds)
 

